@@ -45,6 +45,7 @@ $primary_key = 'Id';
 %fields = map { $_ => $_ } qw(
 Id
 Name
+ExecuteInterval
 Query_json
 AutoArchive
 AutoUnarchive
@@ -54,6 +55,8 @@ AutoEmail
 EmailTo
 EmailSubject
 EmailBody
+EmailServer
+EmailFormat
 AutoMessage
 AutoExecute
 AutoExecuteCmd
@@ -95,7 +98,6 @@ sub Execute {
     $sql =~ s/zmSystemLoad/$load/g;
   }
 
-  $sql .= ' FOR UPDATE' if $$self{LockRows};
 
   Debug("Filter::Execute SQL ($sql)");
   my $sth = $ZoneMinder::Database::dbh->prepare_cached($sql)
@@ -141,8 +143,8 @@ sub Sql {
     }
 
     my $filter_expr = ZoneMinder::General::jsonDecode($self->{Query_json});
-    my $sql = 'SELECT E.*, unix_timestamp(E.StartDateTime) as Time
-         FROM Events as E';
+    my $fields = 'E.*, unix_timestamp(E.StartDateTime) AS Time';
+    my $from = 'Events AS E';
 
     if ( $filter_expr->{terms} ) {
       foreach my $term ( @{$filter_expr->{terms}} ) {
@@ -160,25 +162,36 @@ sub Sql {
           next;
         }
 
-        my $value = $term->{val};
-        my @value_list;
-
         if ( $term->{attr} eq 'AlarmedZoneId' ) {
           $term->{op} = 'EXISTS';
+        } elsif ( $term->{attr} eq 'Tags' ) {
+          $fields .= ', (SELECT Name FROM Tags WHERE Id IN (SELECT TagId FROM Events_Tags WHERE Events_Tags.EventId=E.Id)) As Tags';
+          $self->{Sql} .= 'T.Id';
+          $from .= ' LEFT JOIN Events_Tags AS ET ON E.Id = ET.EventId LEFT JOIN Tags AS T ON T.Id = ET.TagId';
         } elsif ( $term->{attr} =~ /^Monitor/ ) {
-          $sql = 'SELECT E.*, unix_timestamp(E.StartDateTime) as Time, M.Name as MonitorName
-          FROM Events as E INNER JOIN Monitors as M on M.Id = E.MonitorId';
+          if (!($fields =~ /MonitorName/)) {
+            $fields .= ', M.Name as MonitorName';
+            $from .= ' INNER JOIN Monitors as M on M.Id = E.MonitorId';
+          }
           my ( $temp_attr_name ) = $term->{attr} =~ /^Monitor(.+)$/;
-          $self->{Sql} .= 'M.'.$temp_attr_name;
+          $self->{Sql} .= 'M.'.($temp_attr_name ? $temp_attr_name : 'Id');
         } elsif ( $term->{attr} eq 'ServerId' or $term->{attr} eq 'MonitorServerId' ) {
-          $sql = 'SELECT E.*, unix_timestamp(E.StartDateTime) as Time, M.Name as MonitorName
-          FROM Events as E INNER JOIN Monitors as M on M.Id = E.MonitorId';
+          if (!($fields =~ /MonitorName/)) {
+            $fields .= ', M.Name as MonitorName';
+            $from .= ' INNER JOIN Monitors as M on M.Id = E.MonitorId';
+          }
           $self->{Sql} .= 'M.ServerId';
         } elsif ( $term->{attr} eq 'StorageServerId' ) {
           $self->{Sql} .= '(SELECT Storage.ServerId FROM Storage WHERE Storage.Id=E.StorageId)';
         } elsif ( $term->{attr} eq 'FilterServerId' ) {
-          $self->{Sql} .= $Config{ZM_SERVER_ID};
+          $self->{Sql} .= (defined($Config{ZM_SERVER_ID}) ? $Config{ZM_SERVER_ID}: '0').' /* ZM_SERVER_ID */';
           # StartTime options
+        } elsif ( $term->{attr} eq 'CurrentDateTime' ) {
+          $self->{Sql} .= 'NOW()';
+        } elsif ( $term->{attr} eq 'CurrentTime' ) {
+          $self->{Sql} .= 'extract( hour_second from NOW())';
+        } elsif ( $term->{attr} eq 'CurrentDate' ) {
+          $self->{Sql} .= 'to_days(NOW())';
         } elsif ( $term->{attr} eq 'DateTime' ) {
           $self->{Sql} .= 'E.StartDateTime';
         } elsif ( $term->{attr} eq 'Date' ) {
@@ -190,7 +203,7 @@ sub Sql {
         } elsif ( $term->{attr} eq 'Weekday' or $term->{attr} eq 'StartWeekday' ) {
           $self->{Sql} .= 'weekday( E.StartDateTime )';
 
-          # EndTIme options
+          # EndTime options
         } elsif ( $term->{attr} eq 'EndDateTime' ) {
           $self->{Sql} .= 'E.EndDateTime';
         } elsif ( $term->{attr} eq 'EndDate' ) {
@@ -215,18 +228,26 @@ sub Sql {
           $self->{Sql} .= 'E.'.$term->{attr};
         }
 
+        my $value = defined($term->{val}) ? $term->{val} : '';
+        my @value_list;
+
         if ( $term->{attr} eq 'ExistsInFileSystem' ) {
           # PostCondition, so no further SQL
         } else {
-          ( my $stripped_value = $value ) =~ s/^["\']+?(.+)["\']+?$/$1/;
+          my $stripped_value = $value;
+          $stripped_value =~ s/^["\']+?(.+)["\']+?$/$1/ if $stripped_value;
+
           # Empty value will result in () from split
           foreach my $temp_value ( $stripped_value ne '' ? split( /["'\s]*?,["'\s]*?/, $stripped_value ) : $stripped_value ) {
             if ( $term->{attr} eq 'AlarmedZoneId' ) {
               $value = '(SELECT * FROM Stats WHERE EventId=E.Id AND Score > 0 AND ZoneId='.$value.')';
             } elsif ( $term->{attr} =~ /^MonitorName/ ) {
               $value = "'$temp_value'";
-            } elsif ( $term->{attr} =~ /ServerId/) {
-              Debug("ServerId, temp_value is ($temp_value) ($ZoneMinder::Config::Config{ZM_SERVER_ID})");
+            } elsif (
+              $term->{attr} eq 'ServerId' or
+              $term->{attr} eq 'MonitorServerId' or
+              $term->{attr} eq 'StorageServerId' or
+              $term->{attr} eq 'FilterServerId' ) {
               if ( $temp_value eq 'ZM_SERVER_ID' ) {
                 $value = "'$ZoneMinder::Config::Config{ZM_SERVER_ID}'";
                 # This gets used later, I forget for what
@@ -245,6 +266,7 @@ sub Sql {
             } elsif ( $term->{attr} eq 'Name'
               || $term->{attr} eq 'Cause'
               || $term->{attr} eq 'Notes'
+              || $term->{attr} eq 'Tags'
             ) {
               if ( $term->{op} eq 'LIKE'
                 || $term->{op} eq 'NOT LIKE'
@@ -252,7 +274,7 @@ sub Sql {
                 $temp_value = '%'.$temp_value.'%' if $temp_value !~ /%/;
               }
               $value = "'$temp_value'";
-            } elsif ( $term->{attr} eq 'DateTime' or $term->{attr} eq 'StartDateTime' or $term->{attr} eq 'EndDateTime' ) {
+            } elsif ( $term->{attr} eq 'DateTime' or $term->{attr} eq 'StartDateTime' or $term->{attr} eq 'EndDateTime' or $term->{attr} eq 'CurrentDateTime') {
               if ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } else {
@@ -263,7 +285,7 @@ sub Sql {
                 }
                 $value = "'$value'";
               }
-            } elsif ( $term->{attr} eq 'Date' or $term->{attr} eq 'StartDate' or $term->{attr} eq 'EndDate' ) {
+            } elsif ( $term->{attr} eq 'Date' or $term->{attr} eq 'StartDate' or $term->{attr} eq 'EndDate' or $term->{attr} eq 'CurrentDate') {
               if ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } elsif ( $temp_value eq 'CURDATE()' or $temp_value eq 'NOW()' ) {
@@ -276,7 +298,7 @@ sub Sql {
                 }
                 $value = "to_days( '$value' )";
               }
-            } elsif ( $term->{attr} eq 'Time' or $term->{attr} eq 'StartTime' or $term->{attr} eq 'EndTime' ) {
+            } elsif ( $term->{attr} eq 'Time' or $term->{attr} eq 'StartTime' or $term->{attr} eq 'EndTime' or $term->{attr} eq 'CurrentTime') {
               if ( uc($temp_value) eq 'NULL' ) {
                 $value = $temp_value;
               } else {
@@ -303,13 +325,19 @@ sub Sql {
                 $self->{Sql} .= ' % 2 = 1';
               } elsif ( $value eq 'Even' ) {
                 $self->{Sql} .= ' % 2 = 0';
+              } elsif (uc($value) ne 'NULL') {
+                $self->{Sql} .= ' = '.$value;
               } else {
                 $self->{Sql} .= ' IS '.$value;
               }
             } elsif ( $term->{op} eq 'EXISTS' ) {
               $self->{Sql} .= ' EXISTS '.$value;
             } elsif ( $term->{op} eq 'IS NOT' ) {
-              $self->{Sql} .= ' IS NOT '.$value;
+              if (uc($value) ne 'NULL') {
+                $self->{Sql} .= ' != '.$value;
+              } else {
+                $self->{Sql} .= ' IS NOT '.$value;
+              }
             } elsif ( $term->{op} eq '=[]' or $term->{op} eq 'IN' ) {
               $self->{Sql} .= ' IN ('.join(',', @value_list).")";
             } elsif ( $term->{op} eq '![]' or $term->{op} eq 'NOT IN') {
@@ -318,6 +346,8 @@ sub Sql {
               $self->{Sql} .= ' LIKE '.$value;
             } elsif ( $term->{op} eq 'NOT LIKE' ) {
               $self->{Sql} .= ' NOT LIKE '.$value;
+            } elsif ( $term->{attr} eq 'Tags' and ($term->{op} eq 'LIKE' or $term->{op} eq 'IS') and $term->{val} eq '') {
+              $self->{Sql} .= 'NOT EXISTS (SELECT NULL FROM `Events_Tags` AS ET WHERE ET.EventId = E.Id)';
             } else {
               $self->{Sql} .= ' '.$term->{op}.' '.$value;
             }
@@ -328,6 +358,7 @@ sub Sql {
       } # end foreach term
     } # end if terms
 
+    my $sql = ' SELECT '.$fields. ' FROM ' . $from;
     if ( $self->{Sql} ) {
 # Include all events, including events that are still ongoing
 # and have no EndTime yet
@@ -360,27 +391,63 @@ sub Sql {
     if ( @auto_terms ) {
       $sql .= ' AND ( '.join(' or ', @auto_terms).' )';
     }
+
+    my $sort_column = '';
     if ($filter_expr->{sort_field}) {
-      my $sort_column = '';
-      if ( $filter_expr->{sort_field} eq 'MonitorName' ) {
-        $sql = 'SELECT E.*, unix_timestamp(E.StartDateTime) as Time, M.Name as MonitorName
-        FROM Events as E INNER JOIN Monitors as M on M.Id = E.MonitorId';
+      if ( $filter_expr->{sort_field} eq 'Id' ) {
+        $sort_column = 'E.Id';
+      } elsif ( $filter_expr->{sort_field} eq 'Tag' ) {
+        $sort_column = 'T.Name';
+      } elsif ( $filter_expr->{sort_field} eq 'MonitorName' ) {
+        if (!($fields =~ /MonitorName/)) {
+          $fields .= ', M.Name as MonitorName';
+          $from .= ' INNER JOIN Monitors as M on M.Id = E.MonitorId';
+          $sql = ' SELECT '.$fields. ' FROM ' . $from;
+          $sql .= ' WHERE ( '.$self->{Sql}.' )' if $self->{Sql};
+          $sql .= ' AND ( '.join(' or ', @auto_terms).' )' if @auto_terms;
+        }
         $sort_column = 'M.Name';
+      } elsif ( $filter_expr->{sort_field} eq 'Name' ) {
+        $sort_column = 'E.Name';
+      } elsif ( $filter_expr->{sort_field} eq 'StartDateTime' ) {
+        $sort_column = 'E.StartDateTime';
       } elsif ( $filter_expr->{sort_field} eq 'StartTime' ) {
         $sort_column = 'E.StartDateTime';
       } elsif ( $filter_expr->{sort_field} eq 'EndTime' ) {
         $sort_column = 'E.EndDateTime';
+      } elsif ( $filter_expr->{sort_field} eq 'EndDateTime' ) {
+        $sort_column = 'E.EndDateTime';
       } elsif ( $filter_expr->{sort_field} eq 'Secs' ) {
         $sort_column = 'E.Length';
-      } else {
+      } elsif ( $filter_expr->{sort_field} eq 'Frames' ) {
+        $sort_column = 'E.Frames';
+      } elsif ( $filter_expr->{sort_field} eq 'AlarmFrames' ) {
+        $sort_column = 'E.AlarmFrames';
+      } elsif ( $filter_expr->{sort_field} eq 'TotScore' ) {
+        $sort_column = 'E.TotScore';
+      } elsif ( $filter_expr->{sort_field} eq 'AvgScore' ) {
+        $sort_column = 'E.AvgScore';
+      } elsif ( $filter_expr->{sort_field} eq 'MaxScore' ) {
+        $sort_column = 'E.MaxScore';
+      } elsif ( $filter_expr->{sort_field} eq 'DiskSpace' ) {
+        $sort_column = 'E.DiskSpace';
+      } elsif ( $filter_expr->{sort_field} ne '' ) {
         $sort_column = 'E.'.$filter_expr->{sort_field};
       }
-      my $sort_order = $filter_expr->{sort_asc} ? 'ASC' : 'DESC';
-      $sql .= ' ORDER BY '.$sort_column.' '.$sort_order;
     }
-    if ( $filter_expr->{limit} ) {
+    #$sql .= ' GROUP BY E.Id ';
+    if ( $sort_column ne '' ) {
+      $sql .= ' ORDER BY '.$sort_column.' '.($filter_expr->{sort_asc} ? 'ASC' : 'DESC');
+    }
+    if ($filter_expr->{limit}) {
       $sql .= ' LIMIT 0,'.$filter_expr->{limit};
     }
+    if ($$self{LockRows}) {
+      $sql .= ' FOR UPDATE';
+      if ($filter_expr->{skip_locked}) {
+        $sql .= ' SKIP LOCKED';
+      }
+    }
     $self->{Sql} = $sql;
   } # end if has Sql
   return $self->{Sql};
@@ -423,10 +490,7 @@ sub getLoad {
 sub strtotime {
   my $dt_str = shift;
   require Date::Manip;
-
-  Date::Manip::Date_Init("SetDate=now,".$ZoneMinder::Config{ZM_TIMEZONE}) if $ZoneMinder::Config{ZM_TIMEZONE};
-  my $dt = Date::Manip::ParseDate($dt_str);
-  return Date::Manip::UnixDate($dt, '%s');
+  return Date::Manip::UnixDate($dt_str, '%s');
 }
 
 #
