@@ -21,13 +21,6 @@ class MonitorsController extends AppController {
 
   public function beforeFilter() {
     parent::beforeFilter();
-    global $user;
-    # We already tested for auth in appController, so we just need to test for specific permission
-    $canView = (!$user) || ($user['Monitors'] != 'None');
-    if ( !$canView ) {
-      throw new UnauthorizedException(__('Insufficient Privileges'));
-      return;
-    }
   }
 
 /**
@@ -38,43 +31,37 @@ class MonitorsController extends AppController {
   public function index() {
     $this->Monitor->recursive = 0;
 
-    if ( $this->request->params['named'] ) {
+    if ($this->request->params['named']) {
       $this->FilterComponent = $this->Components->load('Filter');
-      //$conditions = $this->FilterComponent->buildFilter($this->request->params['named']);
-      $conditions = $this->request->params['named'];
+      $conditions = $this->FilterComponent->buildFilter($this->request->params['named']);
     } else {
       $conditions = array();
     }
 
-    global $user;
-    $allowedMonitors = $user ? preg_split('@,@', $user['MonitorIds'], NULL, PREG_SPLIT_NO_EMPTY) : null;
-    if ( $allowedMonitors ) {
-      $conditions['Monitor.Id' ] = $allowedMonitors;
-    }
-    $find_array = array('conditions'=>$conditions,'contain'=>array('Group'));
-
-    if ( isset($conditions['GroupId']) ) {
-      $find_array['joins'] = array(
+    $find_array = array(
+      'conditions' => &$conditions,
+      'contain'    => array('Group'),
+      'joins'      => array(
         array(
           'table' => 'Groups_Monitors',
-          'type' => 'inner',
+          'type'  => 'left',
           'conditions' => array(
-            'Groups_Monitors.MonitorId = Monitor.Id'
+            'Groups_Monitors.MonitorId = Monitor.Id',
           ),
         ),
-        //array(
-          //'table' => 'Groups',
-          //'type' => 'inner',
-          //'conditions' => array(
-            //'Groups.Id = Groups_Monitors.GroupId',
-            //'Groups.Id' => $this->request->params['GroupId'],
-          //),
-        //)
-      );
+      ),
+      'group' => '`Monitor`.`Id`'
+    );
+    $monitors = $this->Monitor->find('all', $find_array);
+    $allowed_monitors = [];
+    require_once __DIR__ .'/../../../includes/Monitor.php';
+    foreach ($monitors as $m) {
+      $monitor = new ZM\Monitor($m['Monitor']);
+      if (!$monitor->canView()) continue;
+      array_push($allowed_monitors, $m);
     }
-    $monitors = $this->Monitor->find('all',$find_array);
     $this->set(array(
-          'monitors' => $monitors,
+          'monitors' => $allowed_monitors,
           '_serialize' => array('monitors')
           ));
   }
@@ -88,23 +75,22 @@ class MonitorsController extends AppController {
  */
   public function view($id = null) {
     $this->Monitor->recursive = 0;
-    if ( !$this->Monitor->exists($id) ) {
+    if (!$this->Monitor->exists($id)) {
       throw new NotFoundException(__('Invalid monitor'));
     }
-    global $user;
-    $allowedMonitors = $user ? preg_split('@,@', $user['MonitorIds'], NULL, PREG_SPLIT_NO_EMPTY) : null;
-    if ( $allowedMonitors ) {
-      $restricted = array('Monitor.' . $this->Monitor->primaryKey => $allowedMonitors);
-    } else {
-      $restricted = '';
-    }
     
-    $options = array('conditions' => array( 
-          array('Monitor.' . $this->Monitor->primaryKey => $id),
-          $restricted
-          )
-        );
+    require_once __DIR__ .'/../../../includes/Monitor.php';
+    $options = array('conditions' => array( array('Monitor.'.$this->Monitor->primaryKey => $id)));
     $monitor = $this->Monitor->find('first', $options);
+    $zm_monitor = new ZM\Monitor($monitor['Monitor']);
+    if (!$zm_monitor->canView()) {
+      throw new UnauthorizedException(__('Insufficient Privileges'));
+      return;
+    }
+
+    if ($zm_monitor->JanusEnabled()) {
+      $monitor['Monitor']['Janus_Pin'] = $zm_monitor->Janus_Pin();
+    }
     $this->set(array(
       'monitor' => $monitor,
       '_serialize' => array('monitor')
@@ -120,19 +106,22 @@ class MonitorsController extends AppController {
     if ( $this->request->is('post') ) {
 
       global $user;
-      $canAdd = (!$user) || ($user['System'] == 'Edit' );
+      $canAdd = (!$user) || ($user->System() == 'Edit' || $user->Monitors() == 'Create' );
       if ( !$canAdd ) {
         throw new UnauthorizedException(__('Insufficient privileges'));
         return;
       }
-
       $this->Monitor->create();
-      if ( $this->Monitor->save($this->request->data) ) {
+      if ($this->Monitor->save($this->request->data) ) {
         $this->daemonControl($this->Monitor->id, 'start');
         //return $this->flash(__('The monitor has been saved.'), array('action' => 'index'));
         $message = 'Saved';
       } else {
         $message = 'Error';
+        // if there is a validation message, use it
+        if (!$this->Monitor->validates()) {
+          $message = $this->Monitor->validationErrors;
+       }
       }
       $this->set(array(
         'message' => $message,
@@ -154,36 +143,29 @@ class MonitorsController extends AppController {
     if ( !$this->Monitor->exists($id) ) {
       throw new NotFoundException(__('Invalid monitor'));
     }
-    global $user;
-    $canEdit = (!$user) || ($user['Monitors'] == 'Edit');
-    if ( !$canEdit ) {
-      throw new UnauthorizedException(__('Insufficient privileges'));
+
+    $monitor = $this->Monitor->find('first', array(
+      'conditions' => array('Id' => $id)
+    ))['Monitor'];
+    require_once __DIR__ .'/../../../includes/Monitor.php';
+    $zm_monitor = new ZM\Monitor($monitor);
+    if (!$zm_monitor->canEdit()) {
+      throw new UnauthorizedException(__('Insufficient Privileges'));
       return;
     }
 
     $message = '';
-    if ( $this->Monitor->save($this->request->data) ) {
+    if ($this->Monitor->save($this->request->data)) {
       $message = 'Saved';
-      $Monitor = $this->Monitor->find('first', array(
-        'fields' => array('Function','ServerId'),
+
+      // Stop the monitor. Should happen before saving
+      $this->Monitor->daemonControl($monitor, 'stop');
+      $monitor = $this->Monitor->find('first', array(
         'conditions' => array('Id' => $id)
       ))['Monitor'];
 
-      // - restart or stop this monitor after change
-      $func = $Monitor['Function'];
-      // We don't pass the request data as the monitor object because it may be a subset of the full monitor array
-      $this->daemonControl($this->Monitor->id, 'stop');
-      if (
-        ( $func != 'None' )
-        and
-        (
-          (!defined('ZM_SERVER_ID'))
-          or
-          ($Monitor['ServerId']==ZM_SERVER_ID)
-        )
-      ) {
-        $this->daemonControl($this->Monitor->id, 'start');
-      }
+      if ($monitor['Capturing'] != 'None')
+        $this->Monitor->daemonControl($monitor, 'start');
     } else {
       $message = 'Error ' . print_r($this->Monitor->invalidFields(), true);
     }
@@ -207,8 +189,10 @@ class MonitorsController extends AppController {
     if ( !$this->Monitor->exists() ) {
       throw new NotFoundException(__('Invalid monitor'));
     }
-    if ( $this->Session->Read('systemPermission') != 'Edit' ) {
-       throw new UnauthorizedException(__('Insufficient privileges'));
+    global $user;
+    $canEdit = (!$user) || ($user->System() == 'Edit');
+    if ( !$canEdit ) {
+      throw new UnauthorizedException(__('Insufficient privileges'));
       return;
     }
     $this->request->allowMethod('post', 'delete');
@@ -239,18 +223,14 @@ class MonitorsController extends AppController {
   // arm/disarm alarms
   // expected format: http(s):/portal-api-url/monitors/alarm/id:M/command:C.json
   // where M=monitorId
-  // where C=on|off|status
+  // where C=on|off|status|disable
   public function alarm() {
     $id = $this->request->params['named']['id'];
-    $cmd = strtolower($this->request->params['named']['command']);
     if ( !$this->Monitor->exists($id) ) {
       throw new NotFoundException(__('Invalid monitor'));
     }
-    if ( $cmd != 'on' && $cmd != 'off' && $cmd != 'status' ) {
-      throw new BadRequestException(__('Invalid command'));
-    }
-    $zm_path_bin = Configure::read('ZM_PATH_BIN');
 
+    $cmd = strtolower($this->request->params['named']['command']);
     switch ($cmd) {
       case 'on':
         $q = '-a';
@@ -260,48 +240,75 @@ class MonitorsController extends AppController {
         $q = '-c';
         $verbose = '-v';
         break;
+      case 'disable':
+        $q = '-n';
+        $verbose = '-v';
+        break;
       case 'status':
         $verbose = ''; // zmu has a bug - gives incorrect verbose output in this case
         $q = '-s';
         break;      
+      default :
+        throw new BadRequestException(__('Invalid command'));
     }
 
     // form auth key based on auth credentials
-    $this->loadModel('Config');
-    $options = array('conditions' => array('Config.' . $this->Config->primaryKey => 'ZM_OPT_USE_AUTH'));
-    $config = $this->Config->find('first', $options);
-    $zmOptAuth = $config['Config']['Value'];
-
-    $options = array('conditions' => array('Config.' . $this->Config->primaryKey => 'ZM_AUTH_RELAY'));
-    $config = $this->Config->find('first', $options);
-    $zmAuthRelay = $config['Config']['Value'];
-  
     $auth = '';
-    if ( $zmOptAuth ) {
-      if ( $zmAuthRelay == 'hashed' ) {
-        $options = array('conditions' => array('Config.' . $this->Config->primaryKey => 'ZM_AUTH_HASH_SECRET'));
-        $config = $this->Config->find('first', $options);
-        $zmAuthHashSecret = $config['Config']['Value'];
+    
+    if (ZM_OPT_USE_AUTH) {
+      global $user;
+      $mToken = $this->request->query('token') ? $this->request->query('token') : $this->request->data('token');;
+      if ($mToken) {
+        $auth = ' -T '.$mToken;
+      } else if (ZM_AUTH_RELAY == 'hashed') {
+        $auth = ' -A '.calculateAuthHash(''); # Can't do REMOTE_IP because zmu doesn't normally have access to it.
+      } else if (ZM_AUTH_RELAY == 'plain') {
+        # Plain requires the plain text password which must either be in request or stored in session
+        $password = $this->request->query('pass') ? $this->request->query('pass') : $this->request->data('pass');;
+        if (!$password) 
+          $password = $this->request->query('password') ? $this->request->query('password') : $this->request->data('password');
 
-        $time = localtime();
-        $ak = $zmAuthHashSecret.$this->Session->Read('username').$this->Session->Read('passwordHash').$time[2].$time[3].$time[4].$time[5];
-        $ak = md5($ak);
-        $auth = ' -A '.$ak;
-      } else if ( $zmAuthRelay == 'plain' ) {
-        $auth = ' -U ' .$this->Session->Read('username').' -P '.$this->Session->Read('password');
-        
-      } else if ( $zmAuthRelay == 'none' ) {
-        $auth = ' -U ' .$this->Session->Read('username');
+        if (!$password) {
+          # during auth the session will have been populated with the plaintext password
+          $stateful = $this->request->query('stateful') ? $this->request->query('stateful') : $this->request->data('stateful');
+          if ($stateful) {
+            $password = $_SESSION['password'];
+          }
+        } else if ($_COOKIE['ZMSESSID']) {
+          $password = $_SESSION['password'];
+        }
+
+        $auth = ' -U ' .$user->Username().' -P '.$password;
+      } else if (ZM_AUTH_RELAY == 'none') {
+        $auth = ' -U ' .$user->Username();
       }
     }
     
-    $shellcmd = escapeshellcmd("$zm_path_bin/zmu $verbose -m$id $q $auth");
-    $status = exec ($shellcmd);
-
-    $this->set(array(
-      'status' => $status,
-      '_serialize' => array('status'),
-    ));
+    $shellcmd = escapeshellcmd(ZM_PATH_BIN."/zmu $verbose -m$id $q $auth");
+    $status = exec($shellcmd, $output, $rc);
+    ZM\Debug("Command: $shellcmd output: ".implode(PHP_EOL, $output)." rc: $rc");
+    if ($rc) {
+      $this->set(array(
+        'status'=>'false',
+        'code' => $rc,
+        'error'=> implode(PHP_EOL, $output),
+        '_serialize' => array('status','code','error'),
+      ));
+    } else if ($cmd == 'status') {
+      // In 1.36.16 the values got shifted up so that we could index into an array of strings.
+      // So do a hack to restore the previous behavour
+      $this->set(array(
+        'status' => intval($status)-1,
+        'output' => intval($output[0])-1,
+        '_serialize' => array('status','output'),
+      ));
+    } else {
+      $this->set(array(
+        'status' => $status,
+        'output' => implode(PHP_EOL, $output),
+        '_serialize' => array('status','output'),
+      ));
+    }
   }
 
   // Check if a daemon is running for the monitor id
@@ -313,13 +320,25 @@ class MonitorsController extends AppController {
       throw new NotFoundException(__('Invalid monitor'));
     }
 
+    if (preg_match('/^[a-z]+$/i', $daemon) !== 1) {
+      throw new BadRequestException(__('Invalid command'));
+    }
+
     $monitor = $this->Monitor->find('first', array(
-      'fields' => array('Id', 'Type', 'Device'),
+      'fields' => array('Id', 'Type', 'Device', 'Function'),
       'conditions' => array('Id' => $id)
     ));
 
     // Clean up the returned array
     $monitor = Set::extract('/Monitor/.', $monitor);
+    if ($monitor[0]['Function'] == 'None') {
+      $this->set(array(
+        'status' => false,
+        'statustext' => 'Monitor function is set to None',
+        '_serialize' => array('status','statustext'),
+      ));
+      return;
+    }
 
     // Pass -d for local, otherwise -m
     if ( $monitor[0]['Type'] == 'Local' ) {
@@ -329,9 +348,9 @@ class MonitorsController extends AppController {
     }
 
     // Build the command, and execute it
-    $zm_path_bin = Configure::read('ZM_PATH_BIN');
-    $command = escapeshellcmd("$zm_path_bin/zmdc.pl status $daemon $args");
+    $command = escapeshellcmd(ZM_PATH_BIN."/zmdc.pl status $daemon $args");
     $status = exec($command);
+    ZM\Debug("Command: $command output: $status");
 
     // If 'not' is present, the daemon is not running, so return false
     // https://github.com/ZoneMinder/ZoneMinder/issues/799#issuecomment-108996075
@@ -347,36 +366,20 @@ class MonitorsController extends AppController {
     ));
   }
 
-  public function daemonControl($id, $command, $monitor=null, $daemon=null) {
-    $daemons = array();
+  public function daemonControl($id, $command, $daemon=null) {
+    // Need to see if it is local or remote
+    $monitor = $this->Monitor->find('first', array(
+      'fields' => array('Id', 'Type', 'Function', 'Device', 'ServerId'),
+      'conditions' => array('Id' => $id)
+    ));
+    $monitor = $monitor['Monitor'];
 
-    if ( !$monitor ) {
-      // Need to see if it is local or remote
-      $monitor = $this->Monitor->find('first', array(
-        'fields' => array('Type', 'Function', 'Device'),
-        'conditions' => array('Id' => $id)
-      ));
-      $monitor = $monitor['Monitor'];
-    }
+    $status_text = $this->Monitor->daemonControl($monitor, $command, $daemon);
 
-    if ( $monitor['Function'] == 'Monitor' ) {
-      array_push($daemons, 'zmc');
-    } else {
-      array_push($daemons, 'zmc', 'zma');
-    }
-    
-    $zm_path_bin = Configure::read('ZM_PATH_BIN');
-
-    foreach ( $daemons as $daemon ) {
-      $args = '';
-      if ( $daemon == 'zmc' and $monitor['Type'] == 'Local' ) {
-        $args = '-d ' . $monitor['Device'];
-      } else {
-        $args = '-m ' . $id;
-      }
-
-      $shellcmd = escapeshellcmd("$zm_path_bin/zmdc.pl $command $daemon $args");
-      $status = exec( $shellcmd );
-    }
-  }
+    $this->set(array(
+      'status' => 'ok',
+      'statustext' => $status_text,
+      '_serialize' => array('status','statustext'),
+    ));
+  } // end function daemonControl
 } // end class MonitorsController
