@@ -52,6 +52,23 @@
 // Example
 // header( "Content-Type: text/html; charset=iso-8859-1" );
 
+// You may need to change your locale here if your default one is incorrect for the
+// language described in this file, or if you have multiple languages supported.
+// If you do need to change your locale, be aware that the format of this function
+// is subtlely different in versions of PHP before and after 4.3.0, see
+// http://uk2.php.net/manual/en/function.setlocale.php for details.
+// Also be aware that changing the whole locale may affect some floating point or decimal
+// arithmetic in the database, if this is the case change only the individual locale areas
+// that don't affect this rather than all at once. See the examples below.
+// Finally, depending on your setup, PHP may not enjoy have multiple locales in a shared
+// threaded environment, if you get funny errors it may be this.
+//
+// Examples
+// setlocale( 'LC_ALL', 'en_GB' ); All locale settings pre-4.3.0
+// setlocale( LC_ALL,   'zh_TW' ); All locale settings 4.3.0 and after
+// setlocale( LC_CTYPE, 'zh_TW' ); Character class settings 4.3.0 and after
+// setlocale( LC_TIME,  'zh_TW' ); Date and time formatting 4.3.0 and after
+
 // Simple String Replacements
 $SLANG = array(
     'SystemLog'             => '系統日誌',
@@ -261,7 +278,7 @@ $SLANG = array(
     'Debug'                 => '除錯',
     'DefaultRate'           => '預設 Rate',
     'DefaultScale'          => '預設 Scale',
-    'DefaultCodec'          => '預設 Method For Live View',
+    'DefaultCodec'          => '預設 Method For Event View',
     'DefaultView'           => '預設 View',
     'Deinterlacing'         => 'Deinterlacing',
     'RTSPDescribe'          => 'Use RTSP Response Media URL',
@@ -396,7 +413,7 @@ $SLANG = array(
     'HasTurboTilt'          => '有快速傾斜',
     'HasWhiteSpeed'         => '有白平衡速度',
     'HasZoomSpeed'          => '有縮放速度',
-    'HighBW'                => '高&nbsp;B/W',
+    'Highband'                => '高&nbsp;B/W',
     'High'                  => '高',
     'Home'                  => 'Home',
     'Hostname'              => '主機名稱',
@@ -433,7 +450,7 @@ $SLANG = array(
     'LoggingIn'             => '登入中',
     'Login'                 => '登入',
     'Logout'                => '登出',
-    'LowBW'                 => '低&nbsp;B/W',
+    'Lowband'                 => '低&nbsp;B/W',
     'Low'                   => '低',
     'Main'                  => '主要',
     'Man'                   => '人',
@@ -464,7 +481,7 @@ $SLANG = array(
     'MaxZoomRange'          => '最大縮放範圍',
     'MaxZoomSpeed'          => '最大縮放速度',
     'MaxZoomStep'           => '最大縮放步進',
-    'MediumBW'              => '中&nbsp;B/W',
+    'Medband'              => '中&nbsp;B/W',
     'Medium'                => '中',
     'MinAlarmAreaLtMax'     => 'Minimum alarm area should be less than maximum',
     'MinAlarmAreaUnset'     => 'You must specify the minimum alarm pixel count',
