@@ -52,6 +52,149 @@ if ( !function_exists('imagescale') ) {
   }
 }
 
+if (!empty($_REQUEST['proxy'])) {
+  $url = $_REQUEST['proxy'];
+  if (!$url) {
+    ZM\Warning('No url passed to image proxy');
+    return;
+  }
+
+  $url_parts = parse_url($url);
+  $username = $url_parts['user'];
+  $password = isset($url_parts['pass']) ? $url_parts['pass'] : '';
+
+  $method = 'GET';
+  // preparing http options:
+  $opts = array(
+    'http'=>array(
+      'method'=>$method,
+      #'header'=>"Accept-language: en\r\n" .
+      'ignore_errors'   => true
+      #"Cookie: foo=bar\r\n"
+    ),
+    'ssl'=>array(
+      "verify_peer"=>false,
+      "verify_peer_name"=>false,
+    )
+  );
+  $context = stream_context_create($opts);
+
+  // set no time limit and disable compression:
+  set_time_limit(5);
+  if (function_exists('apache_setenv')) @apache_setenv('no-gzip', 1);
+  @ini_set('zlib.output_compression', 0);
+
+  /* Sends an http request with additional headers shown above */
+  $fp = @fopen($url, 'r', false, $context);
+  if ($fp) {
+    $meta_data = stream_get_meta_data($fp);
+    ZM\Debug(print_r($meta_data, true));
+    foreach ($meta_data['wrapper_data'] as $header) {
+      preg_match('/WWW-Authenticate: Digest (.*)/i', $header, $matches);
+      $nc = 1;
+      if (!empty($matches)) {
+        ZM\Debug("Matched $header");
+        $auth_header = $matches[1];
+        $auth_header_array = explode(',', $auth_header);
+        $parsed = array();
+
+        foreach ($auth_header_array as $pair) {
+          preg_match('/^\s*(\w+)="?(.+)"?\s*$/', $pair, $vals);
+          if (!empty($vals)) {
+            $parsed[$vals[1]] = trim($vals[2], '"');
+          } else {
+            ZM\Debug("Didn't match preg $pair");
+          }
+        }
+        ZM\Debug(print_r($parsed, true));
+
+        $cnonce = uniqid();
+        $response_realm     = (isset($parsed['realm'])) ? $parsed['realm'] : '';
+        $response_nonce     = (isset($parsed['nonce'])) ? $parsed['nonce'] : '';
+        $response_opaque    = (isset($parsed['opaque'])) ? $parsed['opaque'] : '';
+
+        $authenticate1 = md5($username.':'.$response_realm.':'.$password);
+        $authenticate2 = md5($method.':'.$url);
+
+        $digestData = $authenticate1.':'.$response_nonce;
+        if (!empty($parsed['qop'])) {
+          $digestData .= ':' . sprintf('%08x', $nc) . ':' . $cnonce . ':' . $parsed['qop'];
+        }
+        $authenticate_response = md5($digestData.':'.$authenticate2);
+
+        $request = sprintf('Authorization: Digest username="%s", realm="%s", nonce="%s", uri="%s", response="%s"',
+          $username, $response_realm, $response_nonce, $url, $authenticate_response);
+        if (!empty($parsed['opaque'])) $request .= ', opaque="'.$parsed['opaque'].'"';
+        if (!empty($parsed['qop'])) {
+          $request .= ', qop="'.$parsed['qop'].'"';
+          $request .= ', nc="'.sprintf('%08x', $nc).'"';
+          $nc++;
+          $request .= ', cnonce="'.$cnonce.'"';
+        }
+        $request .= ', algorithm="MD5"';
+        ZM\Debug($request);
+
+        $request_header = array($request);
+        $opts['http']['header'] = $request;
+        $context = stream_context_create($opts);
+        $fp = fopen($url, 'r', false, $context);
+        $meta_data = stream_get_meta_data($fp);
+        ZM\Debug(print_r($meta_data, true));
+      } # end if have auth
+    } # end foreach header
+
+    # Read in until we either stop reading or have a second Content-Length
+    $r = '';
+    while (substr_count($r, 'Content-Length') != 2) {
+      $new = fread($fp, 512);
+      if (!$new) break;
+      $r .= $new;
+    }
+    #ZM\Debug($r);
+
+    $start = strpos($r, "\xff");
+    if (false !== $start) {
+      header('Content-type: image/jpeg');
+      $end   = strpos($r, "--\n", $start)-1;
+      if ($end > $start) {
+        $frame = substr($r, $start, $end - $start);
+        ZM\Debug("Start $start end $end");
+        if (imagecreatefromstring($frame)) {
+          echo $frame;
+        }
+      } else {
+        # This is possibly an XSS but I don't see how to get around it other than actually trying to parse it as a valid image first.
+        # So we only output it if imagecreatefromdata succeeds
+        if (imagecreatefromstring($r)) {
+          echo $r;
+        }
+      }
+    } else {
+      $img = imagecreate(320, 240);
+
+      $textbgcolor = imagecolorallocate($img, 0, 0, 0);
+      $textcolor = imagecolorallocate($img, 255, 255, 255);
+
+      imagestring($img, 5, 5, 5, 'Authentication Failed', $textcolor);
+      header('Content-type: image/jpeg');
+      imagejpeg($img);
+    }
+
+    fclose($fp);
+  } else {
+    ZM\Debug("Failed to open $url");
+    $img = imagecreate(320, 200);
+
+    $textbgcolor = imagecolorallocate($img, 0, 0, 0);
+    $textcolor = imagecolorallocate($img, 255, 255, 255);
+
+    imagestring($img, 5, 5, 5, 'Failed to open', $textcolor);
+    header('Content-type: image/jpeg');
+    imagejpeg($img);
+  }
+  return;
+}
+
 $errorText = false;
 $filename = '';
 $Frame = null;
@@ -61,14 +204,7 @@ $media_type='image/jpeg';
 
 if ( empty($_REQUEST['path']) ) {
 
-  // Validate show parameter against allowlist to prevent command injection (CVE-2025-65791)
-  $allowed_show_values = array('capture', 'analyse');
   $show = empty($_REQUEST['show']) ? 'capture' : $_REQUEST['show'];
-  if (!in_array($show, $allowed_show_values)) {
-    header('HTTP/1.0 400 Bad Request');
-    ZM\Error('Invalid show parameter: ' . preg_replace('/[^a-zA-Z0-9_-]/', '', $show));
-    return;
-  }
 
   if ( empty($_REQUEST['fid']) ) {
     header('HTTP/1.0 404 Not Found');
@@ -159,7 +295,7 @@ if ( empty($_REQUEST['path']) ) {
           $path = $Event->Path().'/'.sprintf('%0'.ZM_EVENT_IMAGE_DIGITS.'d', $Frame->FrameId()).'-'.$show.'.jpg';
         } else {
           header('HTTP/1.0 404 Not Found');
-          ZM\Error('No alarm jpg found for event '.$_REQUEST['eid'].' at '.$path);
+          ZM\Debug('No alarm jpg found for event '.$_REQUEST['eid'].' at '.$path);
           return;
         }
       } else {
@@ -188,28 +324,38 @@ if ( empty($_REQUEST['path']) ) {
           $path = $Event->Path().'/'.sprintf('%0'.ZM_EVENT_IMAGE_DIGITS.'d', $Frame->FrameId()).'-'.$show.'.jpg';
         } else {
           if ( $Event->DefaultVideo() ) {
-            // Use escapeshellarg() to prevent command injection
-          $command = ZM_PATH_FFMPEG.' -ss '.escapeshellarg($Frame->Delta()).' -i '.escapeshellarg($Event->Path().'/'.$Event->DefaultVideo()).' -frames:v 1 '.escapeshellarg($path).' 2>&1';
-            #$command ='ffmpeg -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
-            #$command ='ffmpeg -v 0 -i '.$Storage->Path().'/'.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
-            ZM\Debug("Running $command");
-            $output = array();
-            $retval = 0;
-            exec($command, $output, $retval);
-            ZM\Debug("Command: $command, retval: $retval, output: " . implode("\n", $output));
-            if ( ! file_exists($path) ) {
-              header('HTTP/1.0 404 Not Found');
-              ZM\Error('Can\'t create frame images from video for this event '.$Event->DefaultVideo().'
+            $file_path = $Event->Path().'/'.$Event->DefaultVideo();
 
-                Command was: '.$command.'
-
-                Output was: '.implode(PHP_EOL,$output) );
-              return;
+            if (!file_exists($file_path)) {
+              if ($file = find_video($Event->Path())) {
+                $file_path = $Event->Path().'/'.$file;
+              }
             }
-            # Generating an image file will use up more disk space, so update the Event record.
-            if ( $Event->EndDateTime() ) {
-              $Event->DiskSpace(null);
-              $Event->save();
+            if (file_exists($file_path)) {
+              $command = ZM_PATH_FFMPEG.' -ss '. $Frame->Delta() .' -i '.$file_path.' -frames:v 1 '.$path . ' 2>&1';
+              #$command ='ffmpeg -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
+              #$command ='ffmpeg -v 0 -i '.$Storage->Path().'/'.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
+              ZM\Debug("Running $command");
+              $output = array();
+              $retval = 0;
+              exec($command, $output, $retval);
+              ZM\Debug("Command: $command, retval: $retval, output: " . implode("\n", $output));
+              if ( ! file_exists($path) ) {
+                header('HTTP/1.0 404 Not Found');
+                ZM\Error('Can\'t create frame images from video for this event '.$Event->DefaultVideo().'
+
+                  Command was: '.$command.'
+
+                  Output was: '.implode(PHP_EOL,$output) );
+                return;
+              }
+              # Generating an image file will use up more disk space, so update the Event record.
+              if ( $Event->EndDateTime() ) {
+                $Event->DiskSpace(null);
+              }
+            } else {
+              header('HTTP/1.0 404 Not Found');
+              ZM\Error('Can\'t create frame images from missing video file at '.$Event->DefaultVideo());
             }
           } else {
             header('HTTP/1.0 404 Not Found');
@@ -225,31 +371,8 @@ if ( empty($_REQUEST['path']) ) {
     } else {
       $Frame = ZM\Frame::find_one(array('EventId'=>$_REQUEST['eid'], 'FrameId'=>$_REQUEST['fid']));
       if (!$Frame) {
-        $previousBulkFrame = dbFetchOne(
-          'SELECT * FROM Frames WHERE EventId=? AND FrameId < ? ORDER BY FrameID DESC LIMIT 1',
-          NULL, array($_REQUEST['eid'], $_REQUEST['fid'])
-        );
-        $nextBulkFrame = dbFetchOne(
-          'SELECT * FROM Frames WHERE EventId=? AND FrameId > ? ORDER BY FrameID ASC LIMIT 1',
-          NULL, array($_REQUEST['eid'], $_REQUEST['fid'])
-        );
-        if ($previousBulkFrame and $nextBulkFrame) {
-          $Frame = new ZM\Frame($previousBulkFrame);
-          $Frame->FrameId($_REQUEST['fid']);
-
-          $percentage = ($Frame->FrameId() - $previousBulkFrame['FrameId']) / ($nextBulkFrame['FrameId'] - $previousBulkFrame['FrameId']);
-
-          $Frame->Delta($previousBulkFrame['Delta'] + floor( 100* ( $nextBulkFrame['Delta'] - $previousBulkFrame['Delta'] ) * $percentage )/100);
-          ZM\Debug('Got virtual frame from Bulk Frames previous delta: ' . $previousBulkFrame['Delta'] . ' + nextdelta:' . $nextBulkFrame['Delta'] . ' - ' . $previousBulkFrame['Delta'] . ' * ' . $percentage );
-        } else if ($previousBulkFrame) {
-          //If no next Frame we have to pull data from the Event itself
-          $Frame = new ZM\Frame($previousBulkFrame);
-          $Frame->FrameId($_REQUEST['fid']);
-
-          $percentage = ($Frame->FrameId()/$Event->Frames());
-
-          $Frame->Delta(floor($Event->Length() * $percentage));
-        } else {
+        $Frame = $Event->find_virtual_frame($_REQUEST['fid']);
+        if (!$Frame) {
           header('HTTP/1.0 404 Not Found');
           ZM\Error('No Frame found for event('.$_REQUEST['eid'].') and frame id('.$_REQUEST['fid'].')');
           return;
@@ -281,13 +404,19 @@ if ( empty($_REQUEST['path']) ) {
     ZM\Debug("$path does not exist");
     # Generate the frame JPG
     if ( ($show == 'capture') and $Event->DefaultVideo() ) {
-      if ( !file_exists($Event->Path().'/'.$Event->DefaultVideo()) ) {
+      $file_path = $Event->Path().'/'.$Event->DefaultVideo();
+
+      if (!file_exists($file_path)) {
+        if ($file = find_video($Event->Path())) {
+          $file_path = $Event->Path().'/'.$file;
+        }
+      }
+      if (!file_exists($file_path)) {
         header('HTTP/1.0 404 Not Found');
         ZM\Error("Can't create frame images from video because there is no video file for this event at (".$Event->Path().'/'.$Event->DefaultVideo() );
         return;
       }
-      // Use escapeshellarg() to prevent command injection
-      $command = ZM_PATH_FFMPEG.' -ss '.escapeshellarg($Frame->Delta()).' -i '.escapeshellarg($Event->Path().'/'.$Event->DefaultVideo()).' -frames:v 1 '.escapeshellarg($path).' 2>&1';
+      $command = ZM_PATH_FFMPEG.' -ss '. $Frame->Delta() .' -i '.$file_path.' -frames:v 1 '.$path . ' 2>&1';
       #$command ='ffmpeg -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
 #$command ='ffmpeg -v 0 -i '.$Storage->Path().'/'.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
       ZM\Debug("Running $command");
@@ -315,34 +444,6 @@ Output was: '.implode(PHP_EOL,$output) );
       return;
     }
   } # end if ! file_exists($path)
-
-} else {
-  ZM\Warning('Loading images by path is deprecated');
-  $dir_events = realpath(ZM_DIR_EVENTS);
-  $path = realpath($dir_events . '/' . $_REQUEST['path']);
-  $pos = strpos($path, $dir_events);
-
-  if ( $pos == 0 && $pos !== false ) {
-    if ( ! empty($user['MonitorIds']) ) {
-      $imageOk = false;
-      $pathMonId = substr($path, 0, strspn($path, '1234567890'));
-      foreach ( preg_split('/["\'\s]*,["\'\s]*/', $user['MonitorIds']) as $monId ) {
-        if ( $pathMonId == $monId ) {
-          $imageOk = true;
-          break;
-        }
-      }
-      if ( !$imageOk )
-        $errorText = 'No image permissions';
-    }
-  } else {
-    $errorText = 'Invalid image path';
-  }
-  if ( !file_exists($path) ) {
-    header('HTTP/1.0 404 Not Found');
-    ZM\Error("Image not found at $path");
-    return;
-  }
 }
 
 # we now load the actual image to send
@@ -376,17 +477,22 @@ if ( !empty($_REQUEST['height']) ) {
 if ( $errorText ) {
   ZM\Error($errorText);
 } else {
+  # Must lock it because zmc may be still writing the jpg and will have a lock on it.
+  $fp_path = fopen($path, 'r');
+  $lock = flock($fp_path, LOCK_SH);
+  if (!$lock) ZM\Warning("Unable to get a read lock on $path, continuing.");
+
   header('Content-type: '.$media_type);
   header('Cache-Control: max-age=86400');
   header('Expires: '.gmdate('D, d M Y H:i:s \G\M\T', time() + (60 * 60))); // Default set to 1 hour
   header('Pragma: cache');
-  if ( ( $scale==0 || $scale==100 ) && ($width==0) && ($height==0) ) {
+  if (($scale==0 || $scale==100) && ($width==0) && ($height==0)) {
     # This is so that Save Image As give a useful filename
-    if ( $Event ) {
+    if ($Event) {
       $filename = $Event->MonitorId().'_'.$Event->Id().'_'.$Frame->FrameId().'.jpg';
       header('Content-Disposition: inline; filename="' . $filename . '"');
     }
-    if ( !readfile($path) ) {
+    if (!readfile($path)) {
       ZM\Error('No bytes read from '. $path);
     }
   } else {
@@ -397,12 +503,12 @@ if ( $errorText ) {
       $oldWidth = imagesx($i);
       $oldHeight = imagesy($i);
       if ( $width == 0 && $height == 0 ) { // scale has to be set to get here with both zero
-        $width = $oldWidth  * $scale / 100.0;
-        $height= $oldHeight * $scale / 100.0;
+        $width = intval($oldWidth  * $scale / 100.0);
+        $height= intval($oldHeight * $scale / 100.0);
       } elseif ( $width == 0 && $height != 0 ) {
-        $width = ($height * $oldWidth) / $oldHeight;
+        $width = intval(($height * $oldWidth) / $oldHeight);
       } elseif ( $width != 0 && $height == 0 ) {
-        $height = ($width * $oldHeight) / $oldWidth;
+        $height = intval(($width * $oldHeight) / $oldWidth);
 ZM\Debug("Figuring out height using width: $height = ($width * $oldHeight) / $oldWidth");
       }
       if ( $width == $oldWidth && $height == $oldHeight ) {
@@ -416,16 +522,19 @@ ZM\Debug("Figuring out height using width: $height = ($width * $oldHeight) / $ol
       $filename = $Event->MonitorId().'_'.$Event->Id().'_'.$Frame->FrameId()."-${width}x${height}.jpg";
       header('Content-Disposition: inline; filename="' . $filename . '"');
     }
-    if ( !( file_exists($scaled_path) and readfile($scaled_path) ) ) {
-      ZM\Debug("Cached scaled image does not exist at $scaled_path or is no good.. Creating it");
-      if (!$i)
+
+    if (!file_exists($scaled_path)) {
+      ZM\Debug("Cached scaled image does not exist at $scaled_path. Creating it");
+
+      if (!$i) {
         $i = imagecreatefromjpeg($path);
-      if ( !$i) {
+      }
+      if (!$i) {
         ZM\Error('Unable to load jpeg from '.$scaled_path);
         $i  = imagecreatetruecolor($width, $height);
         $bg_colour = imagecolorallocate($i, 255, 255, 255);
         $fg_colour = imagecolorallocate($i, 0, 0, 0);
-        imagefilledrectangle($im, 0, 0, $width, $height, $bg_colour);
+        imagefilledrectangle($i, 0, 0, $width, $height, $bg_colour);
         imagestring($i, 1, 5, 5, 'Unable to load jpeg from  ' . $scaled_path, $fg_colour);
         imagejpeg($i);
       } else {
@@ -436,10 +545,15 @@ ZM\Debug("Figuring out height using width: $height = ($width * $oldHeight) / $ol
         imagedestroy($i);
         imagedestroy($iScale);
         $scaled_jpeg_data = ob_get_contents();
-        file_put_contents($scaled_path, $scaled_jpeg_data);
+        file_put_contents($scaled_path, $scaled_jpeg_data, LOCK_EX);
+
         echo $scaled_jpeg_data;
       }
     } else {
+      $fp_scaled_path = fopen($scaled_path, 'r');
+      $lock = flock($fp_scaled_path, LOCK_SH);
+      if (!$lock) Warning("Unable to get a read lock on $scaled_path, trying to send anyways.");
+
       ZM\Debug("Sending $scaled_path");
       $bytes = readfile($scaled_path);
       if ( !$bytes ) {
@@ -447,6 +561,23 @@ ZM\Debug("Figuring out height using width: $height = ($width * $oldHeight) / $ol
       } else {
         ZM\Debug("$bytes sent");
       }
+      flock($fp_scaled_path, LOCK_UN);
+      fclose($fp_scaled_path);
+    } # end if scaled image doesn't exist or failed sending it
+
+  } # end if scaled or not
+  flock($fp_path, LOCK_UN);
+  fclose($fp_path);
+}
+
+function find_video($path) {
+  # Look for other mp4s
+  if (file_exists($path)) {
+    $files = scandir($path);
+    foreach ($files as $file) {
+      if (preg_match('/.mp4$/i', $file)) {
+        return $file;
+      }
     }
   }
 }
